Skip to main content Module future Copy item path Source pub use future::pending;pub use future::ready;pub use future::Future;pub use future::Pending;pub use future::Ready;CatchUnwind Future for the FutureExt::catch_unwind() method. Fuse Future for the fuse method.Or Future for the or() function and the FutureExt::or() method. PollFn Future for the poll_fn() function. PollOnce Future for the poll_once() function. Race Future for the race() function and the FutureExt::race() method. TryZip Future for the try_zip() function. YieldNow Future for the yield_now() function. Zip Future for the zip() function. FutureExt Extension trait for Future . block_on Blocks the current thread on a future. fuse Fuse a future such that poll will never again be called once it has
completed. This method can be used to turn any Future into a
FusedFuture. or Returns the result of the future that completes first, preferring future1 if both are ready. poll_fn Creates a future from a function returning Poll . poll_once Polls a future just once and returns an Option with the result. race Returns the result of the future that completes first, with no preference if both are ready. race_with_seed Race two futures but with a predefined random seed. timeout If the future completes before the duration has elapsed, then the completed value is returned.
Otherwise, an error is returned and the future is canceled. try_zip Joins two fallible futures, waiting for both to complete or one of them to error. yield_now Wakes the current task and returns Poll::Pending once. zip Joins two futures, waiting for both to complete. Boxed Type alias for Pin<Box<dyn Future<Output = T> + Send + 'static>>. BoxedLocal Type alias for Pin<Box<dyn Future<Output = T> + 'static>>.